package at.technikumwien.movies;

import com.fasterxml.jackson.databind.ObjectMapper;

import javax.ws.rs.client.ClientBuilder;
import javax.ws.rs.client.Entity;
import javax.ws.rs.core.GenericType;
import javax.ws.rs.core.MediaType;
import java.io.FileInputStream;
import java.io.InputStream;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.List;
import java.util.logging.Logger;

public class ActorResourceClient {
    private static final Logger LOGGER = Logger.getLogger(ActorResourceClient.class.getName());

    public static void main(String[] args) throws Exception {

        String filename = "import_actor.json";
        var target = ClientBuilder.newClient()
                .register(new RequestFilter("moviesadmin", "topsecret"))
                .target("http://localhost:8080/movieservice/resources/actor");
        ObjectMapper mapper = new ObjectMapper();
        // Added for supporting data types:
        // https://mvnrepository.com/artifact/com.fasterxml.jackson.datatype/jackson-datatype-jsr310
        mapper.findAndRegisterModules();

        // Read JSON file and convert to java object
        InputStream fileInputStream = new FileInputStream(filename);
        Actor actor = mapper.readValue(fileInputStream, Actor.class);
        fileInputStream.close();
        LOGGER.info("Importing actor from json: " + actor);

        // Import actor into the database
        target.request().post(Entity.entity(actor, MediaType.APPLICATION_JSON), Actor.class);

        // Show all actors
        var actors = target
                .request(MediaType.APPLICATION_JSON)
                .get(new GenericType<List<Actor>>() {});

        System.out.println("All actors:");
        actors.forEach(System.out::println);
    }
}
