package at.technikumwien.movies;

import com.fasterxml.jackson.databind.ObjectMapper;

import javax.ws.rs.client.ClientBuilder;
import javax.ws.rs.client.Entity;
import javax.ws.rs.core.GenericType;
import javax.ws.rs.core.MediaType;
import java.io.FileInputStream;
import java.io.InputStream;
import java.util.List;
import java.util.logging.Logger;

public class StudioResourceClient {
    private static final Logger LOGGER = Logger.getLogger(StudioResourceClient.class.getName());

    public static void main(String[] args) throws Exception {

        String filename = "import_studio.json";
        var target = ClientBuilder.newClient()
                .register(new RequestFilter("moviesadmin", "topsecret"))
                .target("http://localhost:8080/movieservice/resources/studio");
        ObjectMapper mapper = new ObjectMapper();

        // Read JSON file and convert to java object
        InputStream fileInputStream = new FileInputStream(filename);
        Studio studio = mapper.readValue(fileInputStream, Studio.class);
        fileInputStream.close();
        LOGGER.info("Importing studio from json: " + studio);

        // Import studio into the database
        target.request().post(Entity.entity(studio, MediaType.APPLICATION_JSON), Studio.class);

        // Show all studios
        var studios = target
                .request(MediaType.APPLICATION_JSON)
                .get(new GenericType<List<Studio>>() {});

        System.out.println("All studios:");
        studios.forEach(System.out::println);
    }
}
